### This is the replication package of the article "Hierarchical and Hybrid Organizational Structures in Open-Source Software Projects: A Longitudinal Study"

In order to run our R scripts, you need to clone coronet (we have tested our scripts with version 4.1 of coronet, https://github.com/se-sic/coronet/archive/v4.1.zip) into a directory named `coronet`  within this scripts directory.

To extract and preprocess the data from the raw data, we use the tools Codeface and and codeface-extraction. Further information about the data format und structure of the input directories can be found in the [README.md](https://github.com/se-sic/coronet/blob/master/README.md) of coronet. Instead of extracting and preprocessing the data for yourself, we provide pseudonymized data for the 20 subject projects we have analyzed, which can be used as input data for the provided R scripts (see ``input-data.tar.gz``).

Based on the data format which coronet uses, our scripts are able to read and process the data (using coronet). Make sure to use coronet as a sub-module in the coronet directory, as the scripts of coronet will be sourced from our analysis scripts.

Beside the network library coronet, our scripts use several other external packages. In the packrat directory, you can find a snapshot file containing all the packages together with their version number that we have used. (However, keep in mind that the snapshot file contains also packages which we did not use in our analysis.) We used R version 4.1.1 in our setup, but other R versions should also work.

---

Our analysis consists of five scripts:

1. Two configuration scripts: ``configuration.R`` and ``configuration-cli.R``
2. Main script: ``hierarchyAnalysis.R``
3. Two utility scripts: ``hierarchy_additions.R`` and ``hierarchy_util.R``

You have to configure the project to analyze (see constant CASESTUDY) and several other configurtion options (such as time window length, paths to the input data and the desired output path, etc.) in ``configuration.R`` or via command-line arguments (see ``configuration-cli.R``, notice that some configuration options may be not configurable via command line arguments).

After configuration, you can execute the main script via ``Rscript hierarchyAnalysis.R``. This performs the hierarchy analysis for one configured project and one type of networks. The main script sources the configuration script at the beginning and makes use of the utility scripts. You can either use the default values configured in ``configuration.R``, or use the command line interface as follows.

Exemplary script execution call:

```
Rscript hierarchyAnalysis.R -c {project-name} -a _ -t 6months -s --artifact_relation cochange --author_relation {relation} --analysis_range_type threemonth-anonymized -d {path-to-the-input-data} -o {path-were-to-dump-the-output-results}
```

`{project-name}` represents a project, e.g. `gcc`.

`-t` takes a time range such as `3months` or `12months`, for instance.

`{relation}` refers to the kind of network you want to construct and derive the hierarchy from; either `mail` or `issue` or `cochangeMail` or `cochangeIssue` or `cochange`.

`{path-to-the-input-data}` refers to the path where you have stored the input data.

`{path-were-to-dump-the-output-results}` referes a path at which to store all the output data, i.e., plots, csv files, etc.

The parameters `--artifact_relation` and `-a` and `analysis_range_type` are merely irrelevant for the hierarchy analysis. However, these paramter have to specified as stated above for consistency reasons.

---

In case of questions, contact Thomas Bock <bockthom@cs.uni-saarland.de>.
